import io
import base64
import treepoem
from barcode import Code128
from datetime import datetime
from barcode.writer import ImageWriter
import karrio.lib as lib


ORDER_SAMPLE = dict(
    order={
        "id": "ord_028e5cb83814487a9546d0690260f0ee",
        "object_type": "order",
        "order_id": "1073459962",
        "source": "shopify",
        "status": "unfulfilled",
        "shipping_to": {
            "id": "adr_4e038ec1bf4448d284069d0dfd761fb3",
            "postal_code": "E1C4Z8",
            "city": "Moncton",
            "federal_tax_id": None,
            "state_tax_id": None,
            "person_name": "John Doe",
            "company_name": "A corp.",
            "country_code": "CA",
            "email": None,
            "phone_number": "+1 514-000-0000",
            "state_code": "NB",
            "suburb": None,
            "residential": False,
            "address_line1": "125 Church St",
            "address_line2": None,
            "validate_location": False,
            "object_type": "address",
            "validation": None,
        },
        "shipping_from": None,
        "line_items": [
            {
                "id": "cdt_cd32372be5524a2fa492c4af598b7679",
                "weight": 0.75,
                "weight_unit": "KG",
                "description": "Violet Suede Shoes",
                "quantity": 1,
                "unfulfilled_quantity": 1,
                "sku": None,
                "value_amount": 85.95,
                "value_currency": "USD",
                "origin_country": None,
                "parent_id": None,
                "metadata": {
                    "BGM": "040000000000016256",
                    "CTL": "11253678",
                    "DEPT": "DBR128",
                    "XXNC": "138039C01",
                    "NAD_UD": "570162",
                    "RFF_CN": "037-2332855",
                    "RFF_ON": "5424560",
                    "RFF_AEM": "3901L",
                    "RFF_AJY": "907",
                },
                "object_type": "commodity",
            },
            {
                "id": "cdt_71ef30b72d4c4b94882337b44e0d3fb9",
                "weight": 1.7,
                "weight_unit": "KG",
                "description": "Purple Leather Coat",
                "quantity": 1,
                "unfulfilled_quantity": 1,
                "sku": None,
                "value_amount": 129.99,
                "value_currency": "USD",
                "origin_country": None,
                "parent_id": None,
                "metadata": {
                    "BGM": "040000000000016256",
                    "CTL": "11253678",
                    "DEPT": "DBR128",
                    "XXNC": "138039C01",
                    "NAD_UD": "570162",
                    "RFF_CN": "037-2332855",
                    "RFF_ON": "5424560",
                    "RFF_AEM": "3901L",
                    "RFF_AJY": "907",
                },
                "object_type": "commodity",
            },
        ],
        "options": {},
        "metadata": {},
        "shipments": [],
        "test_mode": True,
        "created_at": "2022-03-11 22:33:52.123894+00:00",
    },
)

SHIPMENT_SAMPLE = {
    "shipment": {
        "id": "shp_f49473b250ae45bcb7e2a671f54f40ca",
        "object_type": "shipment",
        "tracking_url": "/v1/trackers/tst_overland/0000000135",
        "shipper": {
            "id": "adr_77cf815a63904280acb908b9357b727b",
            "postal_code": "E1C4Z8",
            "city": "Moncton",
            "federal_tax_id": None,
            "state_tax_id": None,
            "person_name": "John Doe",
            "company_name": "A corp.",
            "country_code": "CA",
            "email": None,
            "phone_number": "+1 514-000-0000",
            "state_code": "NB",
            "suburb": None,
            "residential": False,
            "address_line1": "125 Church St",
            "address_line2": None,
            "validate_location": None,
            "object_type": "address",
            "validation": None,
        },
        "recipient": {
            "id": "adr_470c247fbd6441aaaaf3c282d8e80637",
            "postal_code": "V6M2V9",
            "city": "Vancouver",
            "federal_tax_id": None,
            "state_tax_id": None,
            "person_name": "Jane Doe",
            "company_name": "B corp.",
            "country_code": "CA",
            "email": None,
            "phone_number": "+1 514-000-0000",
            "state_code": "BC",
            "suburb": None,
            "residential": True,
            "address_line1": "5840 Oak St",
            "address_line2": None,
            "validate_location": False,
            "object_type": "address",
            "validation": None,
        },
        "parcels": [
            {
                "id": "pcl_00baac55ac8347718342fdc32f6104f5",
                "weight": 1,
                "width": 33.7,
                "height": 18.2,
                "length": 10,
                "packaging_type": "medium_box",
                "package_preset": None,
                "description": None,
                "content": None,
                "is_document": False,
                "weight_unit": "KG",
                "dimension_unit": "CM",
                "items": [
                    {
                        "id": "cdt_2e947981ee1c4cec995573bc16386f96",
                        "weight": 0.75,
                        "weight_unit": "KG",
                        "description": "Violet Suede Shoes",
                        "quantity": 1,
                        "sku": None,
                        "value_amount": 85.95,
                        "value_currency": "USD",
                        "origin_country": None,
                        "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                        "metadata": {
                            "BGM": "040000000000016256",
                            "CTL": "11253678",
                            "DEPT": "DBR128",
                            "XXNC": "138039C01",
                            "NAD_UD": "570162",
                            "RFF_CN": "037-2332855",
                            "RFF_ON": "5424560",
                            "RFF_AEM": "3901L",
                            "RFF_AJY": "907",
                        },
                        "object_type": "commodity",
                    }
                ],
                "freight_class": None,
                "reference_number": "0000000135",
                "object_type": "parcel",
            },
            {
                "id": "pcl_1e82f5c3cd794daf88eabf206bb362ae",
                "weight": 1,
                "width": 46,
                "height": 38,
                "length": 32,
                "packaging_type": None,
                "package_preset": "canadapost_corrugated_medium_box",
                "description": None,
                "content": None,
                "is_document": False,
                "weight_unit": "KG",
                "dimension_unit": "CM",
                "items": [
                    {
                        "id": "cdt_b262b1d38a4b4ab483422d58a2d9096e",
                        "weight": 2,
                        "weight_unit": "KG",
                        "description": "Purple Leather Coat",
                        "quantity": 1,
                        "sku": None,
                        "value_amount": 349.99,
                        "value_currency": "CAD",
                        "origin_country": None,
                        "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                        "metadata": {
                            "BGM": "040000000000016256",
                            "CTL": "11253678",
                            "DEPT": "DBR128",
                            "XXNC": "138039C01",
                            "NAD_UD": "570162",
                            "RFF_CN": "037-2332855",
                            "RFF_ON": "5424560",
                            "RFF_AEM": "3901L",
                            "RFF_AJY": "907",
                        },
                        "object_type": "commodity",
                    },
                    {
                        "id": "cdt_585a044ba05b4d849caf574eb0653f7e",
                        "weight": 0.75,
                        "weight_unit": "KG",
                        "description": "Violet Suede Shoes",
                        "quantity": 1,
                        "sku": None,
                        "value_amount": 85.95,
                        "value_currency": "USD",
                        "origin_country": None,
                        "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                        "metadata": {
                            "BGM": "040000000000016256",
                            "CTL": "11253678",
                            "DEPT": "DBR128",
                            "XXNC": "138039C01",
                            "NAD_UD": "570162",
                            "RFF_CN": "037-2332855",
                            "RFF_ON": "5424560",
                            "RFF_AEM": "3901L",
                            "RFF_AJY": "907",
                        },
                        "object_type": "commodity",
                    },
                ],
                "reference_number": "0000000134",
                "object_type": "parcel",
            },
        ],
        "services": [],
        "options": {"shipment_date": "2022-03-25"},
        "payment": {"paid_by": "sender", "currency": None, "account_number": None},
        "customs": None,
        "rates": [
            {
                "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                "object_type": "rate",
                "carrier_name": "tst_overland",
                "carrier_id": "tst-overland",
                "currency": "CAD",
                "service": "standard_service",
                "discount": None,
                "base_charge": 200,
                "total_charge": 200,
                "duties_and_taxes": None,
                "transit_days": None,
                "extra_charges": [],
                "meta": {
                    "service_name": "STANDARD SERVICE",
                    "rate_provider": "tst_overland",
                    "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                },
                "test_mode": True,
            }
        ],
        "reference": "Order #1073459962,394873849374",
        "label_type": "PDF",
        "carrier_ids": [],
        "tracker_id": None,
        "created_at": "2022-03-25 13:17:48.646853+00:00",
        "metadata": {"order_ids": "1073459962,394873849374"},
        "messages": [],
        "status": "purchased",
        "carrier_name": "generic",
        "carrier_id": "tst-overland",
        "tracking_number": "0000000135",
        "shipment_identifier": "0000000135",
        "selected_rate": {
            "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
            "object_type": "rate",
            "carrier_name": "tst_overland",
            "carrier_id": "tst-overland",
            "currency": "CAD",
            "service": "standard_service",
            "discount": None,
            "base_charge": 200,
            "total_charge": 200,
            "duties_and_taxes": None,
            "transit_days": None,
            "extra_charges": [],
            "meta": {
                "service_name": "STANDARD SERVICE",
                "rate_provider": "tst_overland",
                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
            },
            "test_mode": True,
        },
        "meta": {
            "service_name": "STANDARD SERVICE",
            "rate_provider": "generic",
            "tracking_numbers": ["0000000135", "0000000134"],
            "tracking_identifiers": ["0000000135", "0000000134"],
        },
        "service": "standard_service",
        "selected_rate_id": "rat_1640580c8c5a454b865f68e8f236d6d9",
        "test_mode": True,
        "label_url": "/v1/shipments/shp_f49473b250ae45bcb7e2a671f54f40ca/label.pdf",
        "invoice_url": None,
    },
    "line_items": [
        {
            "id": "cdt_4b80710300ea4e22b67f6a488e588a34",
            "weight": 0.75,
            "weight_unit": "KG",
            "description": "Violet Suede Shoes",
            "quantity": 2,
            "sku": None,
            "value_amount": 85.95,
            "value_currency": "USD",
            "origin_country": None,
            "parent_id": None,
            "metadata": {
                "BGM": "040000000000016256",
                "CTL": "11253678",
                "DEPT": "DBR128",
                "XXNC": "138039C01",
                "NAD_UD": "570162",
                "RFF_CN": "037-2332855",
                "RFF_ON": "5424560",
                "RFF_AEM": "3901L",
                "RFF_AJY": "907",
            },
            "object_type": "commodity",
            "unfulfilled_quantity": 0,
            "ship_quantity": 2,
            "order": {
                "id": "ord_54ee85d0f8f3419fad189ccb19fde7e7",
                "object_type": "order",
                "order_id": "1073459962",
                "order_date": "2022-03-25",
                "source": "shopify",
                "status": "fulfilled",
                "shipping_to": {
                    "id": "adr_2ffc0e33a1de4b87b7a730965556e705",
                    "postal_code": "V6M2V9",
                    "city": "Vancouver",
                    "federal_tax_id": None,
                    "state_tax_id": None,
                    "person_name": "Jane Doe",
                    "company_name": "B corp.",
                    "country_code": "CA",
                    "email": None,
                    "phone_number": "+1 514-000-0000",
                    "state_code": "BC",
                    "suburb": None,
                    "residential": True,
                    "address_line1": "5840 Oak St",
                    "address_line2": None,
                    "validate_location": False,
                    "object_type": "address",
                    "validation": None,
                },
                "shipping_from": None,
                "line_items": [
                    {
                        "id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                        "weight": 0.75,
                        "weight_unit": "KG",
                        "description": "Violet Suede Shoes",
                        "quantity": 2,
                        "sku": None,
                        "value_amount": 85.95,
                        "value_currency": "USD",
                        "origin_country": None,
                        "parent_id": None,
                        "metadata": {
                            "BGM": "040000000000016256",
                            "CTL": "11253678",
                            "DEPT": "DBR128",
                            "XXNC": "138039C01",
                            "NAD_UD": "570162",
                            "RFF_CN": "037-2332855",
                            "RFF_ON": "5424560",
                            "RFF_AEM": "3901L",
                            "RFF_AJY": "907",
                        },
                        "object_type": "commodity",
                        "unfulfilled_quantity": 0,
                    },
                    {
                        "id": "cdt_83bd8bba49734b69a02309d949848650",
                        "weight": 1.7,
                        "weight_unit": "KG",
                        "description": "Purple Leather Coat",
                        "quantity": 1,
                        "sku": None,
                        "value_amount": 129.99,
                        "value_currency": "USD",
                        "origin_country": None,
                        "parent_id": None,
                        "metadata": {
                            "BGM": "040000000000016256",
                            "CTL": "11253678",
                            "DEPT": "DBR128",
                            "XXNC": "138039C01",
                            "NAD_UD": "570162",
                            "RFF_CN": "037-2332855",
                            "RFF_ON": "5424560",
                            "RFF_AEM": "3901L",
                            "RFF_AJY": "907",
                        },
                        "object_type": "commodity",
                        "unfulfilled_quantity": 0,
                    },
                ],
                "options": {},
                "metadata": {},
                "shipments": [
                    {
                        "id": "shp_ff474b4a2ed34b7396c5c282b66c8593",
                        "object_type": "shipment",
                        "tracking_url": "/v1/trackers/tst_overland/0000000136",
                        "shipper": {
                            "id": "adr_e0f0c569e7f7465e86655673d62064ac",
                            "postal_code": "E1C4Z8",
                            "city": "Moncton",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "John Doe",
                            "company_name": "A corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "NB",
                            "suburb": None,
                            "residential": False,
                            "address_line1": "125 Church St",
                            "address_line2": None,
                            "validate_location": None,
                            "object_type": "address",
                            "validation": None,
                        },
                        "recipient": {
                            "id": "adr_0868f58d5431415cbb6eedba9f353a60",
                            "postal_code": "V6M2V9",
                            "city": "Vancouver",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "Jane Doe",
                            "company_name": "B corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "BC",
                            "suburb": None,
                            "residential": True,
                            "address_line1": "5840 Oak St",
                            "address_line2": None,
                            "validate_location": False,
                            "object_type": "address",
                            "validation": None,
                        },
                        "parcels": [
                            {
                                "id": "pcl_822dbe6e6ebd47fdb8aa27aa17d36c94",
                                "weight": 1,
                                "width": 46,
                                "height": 38,
                                "length": 32,
                                "packaging_type": None,
                                "package_preset": "canadapost_corrugated_medium_box",
                                "description": None,
                                "content": None,
                                "is_document": False,
                                "weight_unit": "KG",
                                "dimension_unit": "CM",
                                "items": [
                                    {
                                        "id": "cdt_3ede5dba79834131917a545089ca36eb",
                                        "weight": 2,
                                        "weight_unit": "KG",
                                        "description": "Purple Leather Coat",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 349.99,
                                        "value_currency": "CAD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                    {
                                        "id": "cdt_fa17bbbedabf40258f921f0596bee83b",
                                        "weight": 1.7,
                                        "weight_unit": "KG",
                                        "description": "Purple Leather Coat",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 129.99,
                                        "value_currency": "USD",
                                        "origin_country": None,
                                        "parent_id": "cdt_83bd8bba49734b69a02309d949848650",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                ],
                                "freight_class": None,
                                "reference_number": "0000000136",
                                "object_type": "parcel",
                            }
                        ],
                        "services": [],
                        "options": {"shipment_date": "2022-03-25"},
                        "payment": {
                            "paid_by": "sender",
                            "currency": None,
                            "account_number": None,
                        },
                        "customs": None,
                        "rates": [
                            {
                                "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                                "object_type": "rate",
                                "carrier_name": "tst_overland",
                                "carrier_id": "tst-overland",
                                "currency": "CAD",
                                "service": "standard_service",
                                "discount": None,
                                "base_charge": 100,
                                "total_charge": 100,
                                "duties_and_taxes": None,
                                "transit_days": None,
                                "extra_charges": [],
                                "meta": {
                                    "service_name": "STANDARD SERVICE",
                                    "rate_provider": "tst_overland",
                                    "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                                },
                                "test_mode": True,
                            }
                        ],
                        "reference": "Order #1073459962,394873849374",
                        "label_type": "PDF",
                        "carrier_ids": [],
                        "tracker_id": None,
                        "created_at": "2022-03-25 13:38:17.742127+00:00",
                        "metadata": {"order_ids": "1073459962,394873849374"},
                        "messages": [],
                        "status": "purchased",
                        "carrier_name": "generic",
                        "carrier_id": "tst-overland",
                        "tracking_number": "0000000136",
                        "shipment_identifier": "0000000136",
                        "selected_rate": {
                            "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 100,
                            "total_charge": 100,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        },
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "generic",
                        },
                        "service": "standard_service",
                        "selected_rate_id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                        "test_mode": True,
                        "label_url": "/v1/shipments/shp_ff474b4a2ed34b7396c5c282b66c8593/label.pdf",
                        "invoice_url": None,
                    },
                    {
                        "id": "shp_f49473b250ae45bcb7e2a671f54f40ca",
                        "object_type": "shipment",
                        "tracking_url": "/v1/trackers/tst_overland/0000000135",
                        "shipper": {
                            "id": "adr_77cf815a63904280acb908b9357b727b",
                            "postal_code": "E1C4Z8",
                            "city": "Moncton",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "John Doe",
                            "company_name": "A corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "NB",
                            "suburb": None,
                            "residential": False,
                            "address_line1": "125 Church St",
                            "address_line2": None,
                            "validate_location": None,
                            "object_type": "address",
                            "validation": None,
                        },
                        "recipient": {
                            "id": "adr_470c247fbd6441aaaaf3c282d8e80637",
                            "postal_code": "V6M2V9",
                            "city": "Vancouver",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "Jane Doe",
                            "company_name": "B corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "BC",
                            "suburb": None,
                            "residential": True,
                            "address_line1": "5840 Oak St",
                            "address_line2": None,
                            "validate_location": False,
                            "object_type": "address",
                            "validation": None,
                        },
                        "parcels": [
                            {
                                "id": "pcl_00baac55ac8347718342fdc32f6104f5",
                                "weight": 1,
                                "width": 33.7,
                                "height": 18.2,
                                "length": 10,
                                "packaging_type": "medium_box",
                                "package_preset": None,
                                "description": None,
                                "content": None,
                                "is_document": False,
                                "weight_unit": "KG",
                                "dimension_unit": "CM",
                                "items": [
                                    {
                                        "id": "cdt_2e947981ee1c4cec995573bc16386f96",
                                        "weight": 0.75,
                                        "weight_unit": "KG",
                                        "description": "Violet Suede Shoes",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 85.95,
                                        "value_currency": "USD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    }
                                ],
                                "freight_class": None,
                                "reference_number": "0000000135",
                                "object_type": "parcel",
                            },
                            {
                                "id": "pcl_1e82f5c3cd794daf88eabf206bb362ae",
                                "weight": 1,
                                "width": 46,
                                "height": 38,
                                "length": 32,
                                "packaging_type": None,
                                "package_preset": "canadapost_corrugated_medium_box",
                                "description": None,
                                "content": None,
                                "is_document": False,
                                "weight_unit": "KG",
                                "dimension_unit": "CM",
                                "items": [
                                    {
                                        "id": "cdt_b262b1d38a4b4ab483422d58a2d9096e",
                                        "weight": 2,
                                        "weight_unit": "KG",
                                        "description": "Purple Leather Coat",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 349.99,
                                        "value_currency": "CAD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                    {
                                        "id": "cdt_585a044ba05b4d849caf574eb0653f7e",
                                        "weight": 0.75,
                                        "weight_unit": "KG",
                                        "description": "Violet Suede Shoes",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 85.95,
                                        "value_currency": "USD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                ],
                                "reference_number": "0000000134",
                                "object_type": "parcel",
                            },
                        ],
                        "services": [],
                        "options": {"shipment_date": "2022-03-25"},
                        "payment": {
                            "paid_by": "sender",
                            "currency": None,
                            "account_number": None,
                        },
                        "customs": None,
                        "rates": [
                            {
                                "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                                "object_type": "rate",
                                "carrier_name": "tst_overland",
                                "carrier_id": "tst-overland",
                                "currency": "CAD",
                                "service": "standard_service",
                                "discount": None,
                                "base_charge": 200,
                                "total_charge": 200,
                                "duties_and_taxes": None,
                                "transit_days": None,
                                "extra_charges": [],
                                "meta": {
                                    "service_name": "STANDARD SERVICE",
                                    "rate_provider": "tst_overland",
                                    "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                                },
                                "test_mode": True,
                            }
                        ],
                        "reference": "Order #1073459962,394873849374",
                        "label_type": "PDF",
                        "carrier_ids": [],
                        "tracker_id": None,
                        "created_at": "2022-03-25 13:17:48.646853+00:00",
                        "metadata": {"order_ids": "1073459962,394873849374"},
                        "messages": [],
                        "status": "purchased",
                        "carrier_name": "generic",
                        "carrier_id": "tst-overland",
                        "tracking_number": "0000000135",
                        "shipment_identifier": "0000000135",
                        "selected_rate": {
                            "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 200,
                            "total_charge": 200,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        },
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "generic",
                            "tracking_numbers": ["0000000135", "0000000134"],
                            "tracking_identifiers": ["0000000135", "0000000134"],
                        },
                        "service": "standard_service",
                        "selected_rate_id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                        "test_mode": True,
                        "label_url": "/v1/shipments/shp_f49473b250ae45bcb7e2a671f54f40ca/label.pdf",
                        "invoice_url": None,
                    },
                ],
                "test_mode": True,
                "created_at": "2022-03-25 11:59:26.589224+00:00",
            },
        },
        {
            "id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
            "weight": 2,
            "weight_unit": "KG",
            "description": "Purple Leather Coat",
            "quantity": 2,
            "sku": None,
            "value_amount": 349.99,
            "value_currency": "CAD",
            "origin_country": None,
            "parent_id": None,
            "metadata": {
                "BGM": "040000000000016256",
                "CTL": "11253678",
                "DEPT": "DBR128",
                "XXNC": "138039C01",
                "NAD_UD": "570162",
                "RFF_CN": "037-2332855",
                "RFF_ON": "5424560",
                "RFF_AEM": "3901L",
                "RFF_AJY": "907",
            },
            "object_type": "commodity",
            "unfulfilled_quantity": 0,
            "ship_quantity": 1,
            "order": {
                "id": "ord_013594df85dc4a4db67c050146b5340d",
                "object_type": "order",
                "order_id": "394873849374",
                "order_date": "2022-03-24",
                "source": "shopify",
                "status": "fulfilled",
                "shipping_to": {
                    "id": "adr_92e11bfba3b84c0180cb73bbd0303b76",
                    "postal_code": "E1C4Z8",
                    "city": "Moncton",
                    "federal_tax_id": None,
                    "state_tax_id": None,
                    "person_name": "John Doe",
                    "company_name": "A corp.",
                    "country_code": "CA",
                    "email": None,
                    "phone_number": "+1 514-000-0000",
                    "state_code": "NB",
                    "suburb": None,
                    "residential": False,
                    "address_line1": "125 Church St",
                    "address_line2": None,
                    "validate_location": False,
                    "object_type": "address",
                    "validation": None,
                },
                "shipping_from": None,
                "line_items": [
                    {
                        "id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                        "weight": 2,
                        "weight_unit": "KG",
                        "description": "Purple Leather Coat",
                        "quantity": 2,
                        "sku": None,
                        "value_amount": 349.99,
                        "value_currency": "CAD",
                        "origin_country": None,
                        "parent_id": None,
                        "metadata": {
                            "BGM": "040000000000016256",
                            "CTL": "11253678",
                            "DEPT": "DBR128",
                            "XXNC": "138039C01",
                            "NAD_UD": "570162",
                            "RFF_CN": "037-2332855",
                            "RFF_ON": "5424560",
                            "RFF_AEM": "3901L",
                            "RFF_AJY": "907",
                        },
                        "object_type": "commodity",
                        "unfulfilled_quantity": 0,
                    }
                ],
                "options": {},
                "metadata": {},
                "shipments": [
                    {
                        "id": "shp_ff474b4a2ed34b7396c5c282b66c8593",
                        "object_type": "shipment",
                        "tracking_url": "/v1/trackers/tst_overland/0000000136",
                        "shipper": {
                            "id": "adr_e0f0c569e7f7465e86655673d62064ac",
                            "postal_code": "E1C4Z8",
                            "city": "Moncton",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "John Doe",
                            "company_name": "A corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "NB",
                            "suburb": None,
                            "residential": False,
                            "address_line1": "125 Church St",
                            "address_line2": None,
                            "validate_location": None,
                            "object_type": "address",
                            "validation": None,
                        },
                        "recipient": {
                            "id": "adr_0868f58d5431415cbb6eedba9f353a60",
                            "postal_code": "V6M2V9",
                            "city": "Vancouver",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "Jane Doe",
                            "company_name": "B corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "BC",
                            "suburb": None,
                            "residential": True,
                            "address_line1": "5840 Oak St",
                            "address_line2": None,
                            "validate_location": False,
                            "object_type": "address",
                            "validation": None,
                        },
                        "parcels": [
                            {
                                "id": "pcl_822dbe6e6ebd47fdb8aa27aa17d36c94",
                                "weight": 1,
                                "width": 46,
                                "height": 38,
                                "length": 32,
                                "packaging_type": None,
                                "package_preset": "canadapost_corrugated_medium_box",
                                "description": None,
                                "content": None,
                                "is_document": False,
                                "weight_unit": "KG",
                                "dimension_unit": "CM",
                                "items": [
                                    {
                                        "id": "cdt_3ede5dba79834131917a545089ca36eb",
                                        "weight": 2,
                                        "weight_unit": "KG",
                                        "description": "Purple Leather Coat",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 349.99,
                                        "value_currency": "CAD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                    {
                                        "id": "cdt_fa17bbbedabf40258f921f0596bee83b",
                                        "weight": 1.7,
                                        "weight_unit": "KG",
                                        "description": "Purple Leather Coat",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 129.99,
                                        "value_currency": "USD",
                                        "origin_country": None,
                                        "parent_id": "cdt_83bd8bba49734b69a02309d949848650",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                ],
                                "freight_class": None,
                                "reference_number": "0000000136",
                                "object_type": "parcel",
                            }
                        ],
                        "services": [],
                        "options": {"shipment_date": "2022-03-25"},
                        "payment": {
                            "paid_by": "sender",
                            "currency": None,
                            "account_number": None,
                        },
                        "customs": None,
                        "rates": [
                            {
                                "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                                "object_type": "rate",
                                "carrier_name": "tst_overland",
                                "carrier_id": "tst-overland",
                                "currency": "CAD",
                                "service": "standard_service",
                                "discount": None,
                                "base_charge": 100,
                                "total_charge": 100,
                                "duties_and_taxes": None,
                                "transit_days": None,
                                "extra_charges": [],
                                "meta": {
                                    "service_name": "STANDARD SERVICE",
                                    "rate_provider": "tst_overland",
                                    "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                                },
                                "test_mode": True,
                            }
                        ],
                        "reference": "Order #1073459962,394873849374",
                        "label_type": "PDF",
                        "carrier_ids": [],
                        "tracker_id": None,
                        "created_at": "2022-03-25 13:38:17.742127+00:00",
                        "metadata": {"order_ids": "1073459962,394873849374"},
                        "messages": [],
                        "status": "purchased",
                        "carrier_name": "generic",
                        "carrier_id": "tst-overland",
                        "tracking_number": "0000000136",
                        "shipment_identifier": "0000000136",
                        "selected_rate": {
                            "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 100,
                            "total_charge": 100,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        },
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "generic",
                        },
                        "service": "standard_service",
                        "selected_rate_id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                        "test_mode": True,
                        "label_url": "/v1/shipments/shp_ff474b4a2ed34b7396c5c282b66c8593/label.pdf",
                        "invoice_url": None,
                    },
                    {
                        "id": "shp_f49473b250ae45bcb7e2a671f54f40ca",
                        "object_type": "shipment",
                        "tracking_url": "/v1/trackers/tst_overland/0000000135",
                        "shipper": {
                            "id": "adr_77cf815a63904280acb908b9357b727b",
                            "postal_code": "E1C4Z8",
                            "city": "Moncton",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "John Doe",
                            "company_name": "A corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "NB",
                            "suburb": None,
                            "residential": False,
                            "address_line1": "125 Church St",
                            "address_line2": None,
                            "validate_location": None,
                            "object_type": "address",
                            "validation": None,
                        },
                        "recipient": {
                            "id": "adr_470c247fbd6441aaaaf3c282d8e80637",
                            "postal_code": "V6M2V9",
                            "city": "Vancouver",
                            "federal_tax_id": None,
                            "state_tax_id": None,
                            "person_name": "Jane Doe",
                            "company_name": "B corp.",
                            "country_code": "CA",
                            "email": None,
                            "phone_number": "+1 514-000-0000",
                            "state_code": "BC",
                            "suburb": None,
                            "residential": True,
                            "address_line1": "5840 Oak St",
                            "address_line2": None,
                            "validate_location": False,
                            "object_type": "address",
                            "validation": None,
                        },
                        "parcels": [
                            {
                                "id": "pcl_00baac55ac8347718342fdc32f6104f5",
                                "weight": 1,
                                "width": 33.7,
                                "height": 18.2,
                                "length": 10,
                                "packaging_type": "medium_box",
                                "package_preset": None,
                                "description": None,
                                "content": None,
                                "is_document": False,
                                "weight_unit": "KG",
                                "dimension_unit": "CM",
                                "items": [
                                    {
                                        "id": "cdt_2e947981ee1c4cec995573bc16386f96",
                                        "weight": 0.75,
                                        "weight_unit": "KG",
                                        "description": "Violet Suede Shoes",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 85.95,
                                        "value_currency": "USD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    }
                                ],
                                "freight_class": None,
                                "reference_number": "0000000135",
                                "object_type": "parcel",
                            },
                            {
                                "id": "pcl_1e82f5c3cd794daf88eabf206bb362ae",
                                "weight": 1,
                                "width": 46,
                                "height": 38,
                                "length": 32,
                                "packaging_type": None,
                                "package_preset": "canadapost_corrugated_medium_box",
                                "description": None,
                                "content": None,
                                "is_document": False,
                                "weight_unit": "KG",
                                "dimension_unit": "CM",
                                "items": [
                                    {
                                        "id": "cdt_b262b1d38a4b4ab483422d58a2d9096e",
                                        "weight": 2,
                                        "weight_unit": "KG",
                                        "description": "Purple Leather Coat",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 349.99,
                                        "value_currency": "CAD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                    {
                                        "id": "cdt_585a044ba05b4d849caf574eb0653f7e",
                                        "weight": 0.75,
                                        "weight_unit": "KG",
                                        "description": "Violet Suede Shoes",
                                        "quantity": 1,
                                        "sku": None,
                                        "value_amount": 85.95,
                                        "value_currency": "USD",
                                        "origin_country": None,
                                        "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                        "metadata": {
                                            "BGM": "040000000000016256",
                                            "CTL": "11253678",
                                            "DEPT": "DBR128",
                                            "XXNC": "138039C01",
                                            "NAD_UD": "570162",
                                            "RFF_CN": "037-2332855",
                                            "RFF_ON": "5424560",
                                            "RFF_AEM": "3901L",
                                            "RFF_AJY": "907",
                                        },
                                        "object_type": "commodity",
                                    },
                                ],
                                "reference_number": "0000000134",
                                "object_type": "parcel",
                            },
                        ],
                        "services": [],
                        "options": {"shipment_date": "2022-03-25"},
                        "payment": {
                            "paid_by": "sender",
                            "currency": None,
                            "account_number": None,
                        },
                        "customs": None,
                        "rates": [
                            {
                                "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                                "object_type": "rate",
                                "carrier_name": "tst_overland",
                                "carrier_id": "tst-overland",
                                "currency": "CAD",
                                "service": "standard_service",
                                "discount": None,
                                "base_charge": 200,
                                "total_charge": 200,
                                "duties_and_taxes": None,
                                "transit_days": None,
                                "extra_charges": [],
                                "meta": {
                                    "service_name": "STANDARD SERVICE",
                                    "rate_provider": "tst_overland",
                                    "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                                },
                                "test_mode": True,
                            }
                        ],
                        "reference": "Order #1073459962,394873849374",
                        "label_type": "PDF",
                        "carrier_ids": [],
                        "tracker_id": None,
                        "created_at": "2022-03-25 13:17:48.646853+00:00",
                        "metadata": {"order_ids": "1073459962,394873849374"},
                        "messages": [],
                        "status": "purchased",
                        "carrier_name": "generic",
                        "carrier_id": "tst-overland",
                        "tracking_number": "0000000135",
                        "shipment_identifier": "0000000135",
                        "selected_rate": {
                            "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 200,
                            "total_charge": 200,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        },
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "generic",
                            "tracking_numbers": ["0000000135", "0000000134"],
                            "tracking_identifiers": ["0000000135", "0000000134"],
                        },
                        "service": "standard_service",
                        "selected_rate_id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                        "test_mode": True,
                        "label_url": "/v1/shipments/shp_f49473b250ae45bcb7e2a671f54f40ca/label.pdf",
                        "invoice_url": None,
                    },
                ],
                "test_mode": True,
                "created_at": "2022-03-21 14:21:55.986000+00:00",
            },
        },
    ],
    "carrier": {
        "id": "car_9dac728533e841b09ec453178de5b3c3",
        "carrier_name": "generic",
        "carrier_id": "tst-overland",
        "test": True,
        "active": True,
        "object_type": "carrier",
        "display_name": "Custom Carrier",
        "metadata": {"APP_ID": "00", "SERIAL": "00099999000"},
    },
    "orders": [
        {
            "id": "ord_54ee85d0f8f3419fad189ccb19fde7e7",
            "object_type": "order",
            "order_id": "1073459962",
            "order_date": "2022-03-25",
            "source": "shopify",
            "status": "fulfilled",
            "shipping_to": {
                "id": "adr_2ffc0e33a1de4b87b7a730965556e705",
                "postal_code": "V6M2V9",
                "city": "Vancouver",
                "federal_tax_id": None,
                "state_tax_id": None,
                "person_name": "Jane Doe",
                "company_name": "B corp.",
                "country_code": "CA",
                "email": None,
                "phone_number": "+1 514-000-0000",
                "state_code": "BC",
                "suburb": None,
                "residential": True,
                "address_line1": "5840 Oak St",
                "address_line2": None,
                "validate_location": False,
                "object_type": "address",
                "validation": None,
            },
            "shipping_from": None,
            "line_items": [
                {
                    "id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                    "weight": 0.75,
                    "weight_unit": "KG",
                    "description": "Violet Suede Shoes",
                    "quantity": 2,
                    "sku": None,
                    "value_amount": 85.95,
                    "value_currency": "USD",
                    "origin_country": None,
                    "parent_id": None,
                    "metadata": {
                        "BGM": "040000000000016256",
                        "CTL": "11253678",
                        "DEPT": "DBR128",
                        "XXNC": "138039C01",
                        "NAD_UD": "570162",
                        "RFF_CN": "037-2332855",
                        "RFF_ON": "5424560",
                        "RFF_AEM": "3901L",
                        "RFF_AJY": "907",
                    },
                    "object_type": "commodity",
                    "unfulfilled_quantity": 0,
                },
                {
                    "id": "cdt_83bd8bba49734b69a02309d949848650",
                    "weight": 1.7,
                    "weight_unit": "KG",
                    "description": "Purple Leather Coat",
                    "quantity": 1,
                    "sku": None,
                    "value_amount": 129.99,
                    "value_currency": "USD",
                    "origin_country": None,
                    "parent_id": None,
                    "metadata": {
                        "BGM": "040000000000016256",
                        "CTL": "11253678",
                        "DEPT": "DBR128",
                        "XXNC": "138039C01",
                        "NAD_UD": "570162",
                        "RFF_CN": "037-2332855",
                        "RFF_ON": "5424560",
                        "RFF_AEM": "3901L",
                        "RFF_AJY": "907",
                    },
                    "object_type": "commodity",
                    "unfulfilled_quantity": 0,
                },
            ],
            "options": {},
            "metadata": {},
            "shipments": [
                {
                    "id": "shp_ff474b4a2ed34b7396c5c282b66c8593",
                    "object_type": "shipment",
                    "tracking_url": "/v1/trackers/tst_overland/0000000136",
                    "shipper": {
                        "id": "adr_e0f0c569e7f7465e86655673d62064ac",
                        "postal_code": "E1C4Z8",
                        "city": "Moncton",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "John Doe",
                        "company_name": "A corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "NB",
                        "suburb": None,
                        "residential": False,
                        "address_line1": "125 Church St",
                        "address_line2": None,
                        "validate_location": None,
                        "object_type": "address",
                        "validation": None,
                    },
                    "recipient": {
                        "id": "adr_0868f58d5431415cbb6eedba9f353a60",
                        "postal_code": "V6M2V9",
                        "city": "Vancouver",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "Jane Doe",
                        "company_name": "B corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "BC",
                        "suburb": None,
                        "residential": True,
                        "address_line1": "5840 Oak St",
                        "address_line2": None,
                        "validate_location": False,
                        "object_type": "address",
                        "validation": None,
                    },
                    "parcels": [
                        {
                            "id": "pcl_822dbe6e6ebd47fdb8aa27aa17d36c94",
                            "weight": 1,
                            "width": 46,
                            "height": 38,
                            "length": 32,
                            "packaging_type": None,
                            "package_preset": "canadapost_corrugated_medium_box",
                            "description": None,
                            "content": None,
                            "is_document": False,
                            "weight_unit": "KG",
                            "dimension_unit": "CM",
                            "items": [
                                {
                                    "id": "cdt_3ede5dba79834131917a545089ca36eb",
                                    "weight": 2,
                                    "weight_unit": "KG",
                                    "description": "Purple Leather Coat",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 349.99,
                                    "value_currency": "CAD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                                {
                                    "id": "cdt_fa17bbbedabf40258f921f0596bee83b",
                                    "weight": 1.7,
                                    "weight_unit": "KG",
                                    "description": "Purple Leather Coat",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 129.99,
                                    "value_currency": "USD",
                                    "origin_country": None,
                                    "parent_id": "cdt_83bd8bba49734b69a02309d949848650",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                            ],
                            "freight_class": None,
                            "reference_number": "0000000136",
                            "object_type": "parcel",
                        }
                    ],
                    "services": [],
                    "options": {"shipment_date": "2022-03-25"},
                    "payment": {
                        "paid_by": "sender",
                        "currency": None,
                        "account_number": None,
                    },
                    "customs": None,
                    "rates": [
                        {
                            "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 100,
                            "total_charge": 100,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        }
                    ],
                    "reference": "Order #1073459962,394873849374",
                    "label_type": "PDF",
                    "carrier_ids": [],
                    "tracker_id": None,
                    "created_at": "2022-03-25 13:38:17.742127+00:00",
                    "metadata": {"order_ids": "1073459962,394873849374"},
                    "messages": [],
                    "status": "purchased",
                    "carrier_name": "generic",
                    "carrier_id": "tst-overland",
                    "tracking_number": "0000000136",
                    "shipment_identifier": "0000000136",
                    "selected_rate": {
                        "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                        "object_type": "rate",
                        "carrier_name": "tst_overland",
                        "carrier_id": "tst-overland",
                        "currency": "CAD",
                        "service": "standard_service",
                        "discount": None,
                        "base_charge": 100,
                        "total_charge": 100,
                        "duties_and_taxes": None,
                        "transit_days": None,
                        "extra_charges": [],
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "tst_overland",
                            "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                        },
                        "test_mode": True,
                    },
                    "meta": {
                        "service_name": "STANDARD SERVICE",
                        "rate_provider": "generic",
                    },
                    "service": "standard_service",
                    "selected_rate_id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                    "test_mode": True,
                    "label_url": "/v1/shipments/shp_ff474b4a2ed34b7396c5c282b66c8593/label.pdf",
                    "invoice_url": None,
                },
                {
                    "id": "shp_f49473b250ae45bcb7e2a671f54f40ca",
                    "object_type": "shipment",
                    "tracking_url": "/v1/trackers/tst_overland/0000000135",
                    "shipper": {
                        "id": "adr_77cf815a63904280acb908b9357b727b",
                        "postal_code": "E1C4Z8",
                        "city": "Moncton",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "John Doe",
                        "company_name": "A corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "NB",
                        "suburb": None,
                        "residential": False,
                        "address_line1": "125 Church St",
                        "address_line2": None,
                        "validate_location": None,
                        "object_type": "address",
                        "validation": None,
                    },
                    "recipient": {
                        "id": "adr_470c247fbd6441aaaaf3c282d8e80637",
                        "postal_code": "V6M2V9",
                        "city": "Vancouver",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "Jane Doe",
                        "company_name": "B corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "BC",
                        "suburb": None,
                        "residential": True,
                        "address_line1": "5840 Oak St",
                        "address_line2": None,
                        "validate_location": False,
                        "object_type": "address",
                        "validation": None,
                    },
                    "parcels": [
                        {
                            "id": "pcl_00baac55ac8347718342fdc32f6104f5",
                            "weight": 1,
                            "width": 33.7,
                            "height": 18.2,
                            "length": 10,
                            "packaging_type": "medium_box",
                            "package_preset": None,
                            "description": None,
                            "content": None,
                            "is_document": False,
                            "weight_unit": "KG",
                            "dimension_unit": "CM",
                            "items": [
                                {
                                    "id": "cdt_2e947981ee1c4cec995573bc16386f96",
                                    "weight": 0.75,
                                    "weight_unit": "KG",
                                    "description": "Violet Suede Shoes",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 85.95,
                                    "value_currency": "USD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                }
                            ],
                            "freight_class": None,
                            "reference_number": "0000000135",
                            "object_type": "parcel",
                        },
                        {
                            "id": "pcl_1e82f5c3cd794daf88eabf206bb362ae",
                            "weight": 1,
                            "width": 46,
                            "height": 38,
                            "length": 32,
                            "packaging_type": None,
                            "package_preset": "canadapost_corrugated_medium_box",
                            "description": None,
                            "content": None,
                            "is_document": False,
                            "weight_unit": "KG",
                            "dimension_unit": "CM",
                            "items": [
                                {
                                    "id": "cdt_b262b1d38a4b4ab483422d58a2d9096e",
                                    "weight": 2,
                                    "weight_unit": "KG",
                                    "description": "Purple Leather Coat",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 349.99,
                                    "value_currency": "CAD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                                {
                                    "id": "cdt_585a044ba05b4d849caf574eb0653f7e",
                                    "weight": 0.75,
                                    "weight_unit": "KG",
                                    "description": "Violet Suede Shoes",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 85.95,
                                    "value_currency": "USD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                            ],
                            "reference_number": "0000000134",
                            "object_type": "parcel",
                        },
                    ],
                    "services": [],
                    "options": {"shipment_date": "2022-03-25"},
                    "payment": {
                        "paid_by": "sender",
                        "currency": None,
                        "account_number": None,
                    },
                    "customs": None,
                    "rates": [
                        {
                            "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 200,
                            "total_charge": 200,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        }
                    ],
                    "reference": "Order #1073459962,394873849374",
                    "label_type": "PDF",
                    "carrier_ids": [],
                    "tracker_id": None,
                    "created_at": "2022-03-25 13:17:48.646853+00:00",
                    "metadata": {"order_ids": "1073459962,394873849374"},
                    "messages": [],
                    "status": "purchased",
                    "carrier_name": "generic",
                    "carrier_id": "tst-overland",
                    "tracking_number": "0000000135",
                    "shipment_identifier": "0000000135",
                    "selected_rate": {
                        "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                        "object_type": "rate",
                        "carrier_name": "tst_overland",
                        "carrier_id": "tst-overland",
                        "currency": "CAD",
                        "service": "standard_service",
                        "discount": None,
                        "base_charge": 200,
                        "total_charge": 200,
                        "duties_and_taxes": None,
                        "transit_days": None,
                        "extra_charges": [],
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "tst_overland",
                            "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                        },
                        "test_mode": True,
                    },
                    "meta": {
                        "service_name": "STANDARD SERVICE",
                        "rate_provider": "generic",
                        "tracking_numbers": ["0000000135", "0000000134"],
                        "tracking_identifiers": ["0000000135", "0000000134"],
                    },
                    "service": "standard_service",
                    "selected_rate_id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                    "test_mode": True,
                    "label_url": "/v1/shipments/shp_f49473b250ae45bcb7e2a671f54f40ca/label.pdf",
                    "invoice_url": None,
                },
            ],
            "test_mode": True,
            "created_at": "2022-03-25 11:59:26.589224+00:00",
        },
        {
            "id": "ord_013594df85dc4a4db67c050146b5340d",
            "object_type": "order",
            "order_id": "394873849374",
            "order_date": "2022-03-24",
            "source": "shopify",
            "status": "fulfilled",
            "shipping_to": {
                "id": "adr_92e11bfba3b84c0180cb73bbd0303b76",
                "postal_code": "E1C4Z8",
                "city": "Moncton",
                "federal_tax_id": None,
                "state_tax_id": None,
                "person_name": "John Doe",
                "company_name": "A corp.",
                "country_code": "CA",
                "email": None,
                "phone_number": "+1 514-000-0000",
                "state_code": "NB",
                "suburb": None,
                "residential": False,
                "address_line1": "125 Church St",
                "address_line2": None,
                "validate_location": False,
                "object_type": "address",
                "validation": None,
            },
            "shipping_from": None,
            "line_items": [
                {
                    "id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                    "weight": 2,
                    "weight_unit": "KG",
                    "description": "Purple Leather Coat",
                    "quantity": 2,
                    "sku": None,
                    "value_amount": 349.99,
                    "value_currency": "CAD",
                    "origin_country": None,
                    "parent_id": None,
                    "metadata": {
                        "BGM": "040000000000016256",
                        "CTL": "11253678",
                        "DEPT": "DBR128",
                        "XXNC": "138039C01",
                        "NAD_UD": "570162",
                        "RFF_CN": "037-2332855",
                        "RFF_ON": "5424560",
                        "RFF_AEM": "3901L",
                        "RFF_AJY": "907",
                    },
                    "object_type": "commodity",
                    "unfulfilled_quantity": 0,
                }
            ],
            "options": {},
            "metadata": {},
            "shipments": [
                {
                    "id": "shp_ff474b4a2ed34b7396c5c282b66c8593",
                    "object_type": "shipment",
                    "tracking_url": "/v1/trackers/tst_overland/0000000136",
                    "shipper": {
                        "id": "adr_e0f0c569e7f7465e86655673d62064ac",
                        "postal_code": "E1C4Z8",
                        "city": "Moncton",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "John Doe",
                        "company_name": "A corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "NB",
                        "suburb": None,
                        "residential": False,
                        "address_line1": "125 Church St",
                        "address_line2": None,
                        "validate_location": None,
                        "object_type": "address",
                        "validation": None,
                    },
                    "recipient": {
                        "id": "adr_0868f58d5431415cbb6eedba9f353a60",
                        "postal_code": "V6M2V9",
                        "city": "Vancouver",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "Jane Doe",
                        "company_name": "B corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "BC",
                        "suburb": None,
                        "residential": True,
                        "address_line1": "5840 Oak St",
                        "address_line2": None,
                        "validate_location": False,
                        "object_type": "address",
                        "validation": None,
                    },
                    "parcels": [
                        {
                            "id": "pcl_822dbe6e6ebd47fdb8aa27aa17d36c94",
                            "weight": 1,
                            "width": 46,
                            "height": 38,
                            "length": 32,
                            "packaging_type": None,
                            "package_preset": "canadapost_corrugated_medium_box",
                            "description": None,
                            "content": None,
                            "is_document": False,
                            "weight_unit": "KG",
                            "dimension_unit": "CM",
                            "items": [
                                {
                                    "id": "cdt_3ede5dba79834131917a545089ca36eb",
                                    "weight": 2,
                                    "weight_unit": "KG",
                                    "description": "Purple Leather Coat",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 349.99,
                                    "value_currency": "CAD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                                {
                                    "id": "cdt_fa17bbbedabf40258f921f0596bee83b",
                                    "weight": 1.7,
                                    "weight_unit": "KG",
                                    "description": "Purple Leather Coat",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 129.99,
                                    "value_currency": "USD",
                                    "origin_country": None,
                                    "parent_id": "cdt_83bd8bba49734b69a02309d949848650",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                            ],
                            "freight_class": None,
                            "reference_number": "0000000136",
                            "object_type": "parcel",
                        }
                    ],
                    "services": [],
                    "options": {"shipment_date": "2022-03-25"},
                    "payment": {
                        "paid_by": "sender",
                        "currency": None,
                        "account_number": None,
                    },
                    "customs": None,
                    "rates": [
                        {
                            "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 100,
                            "total_charge": 100,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        }
                    ],
                    "reference": "Order #1073459962,394873849374",
                    "label_type": "PDF",
                    "carrier_ids": [],
                    "tracker_id": None,
                    "created_at": "2022-03-25 13:38:17.742127+00:00",
                    "metadata": {"order_ids": "1073459962,394873849374"},
                    "messages": [],
                    "status": "purchased",
                    "carrier_name": "generic",
                    "carrier_id": "tst-overland",
                    "tracking_number": "0000000136",
                    "shipment_identifier": "0000000136",
                    "selected_rate": {
                        "id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                        "object_type": "rate",
                        "carrier_name": "tst_overland",
                        "carrier_id": "tst-overland",
                        "currency": "CAD",
                        "service": "standard_service",
                        "discount": None,
                        "base_charge": 100,
                        "total_charge": 100,
                        "duties_and_taxes": None,
                        "transit_days": None,
                        "extra_charges": [],
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "tst_overland",
                            "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                        },
                        "test_mode": True,
                    },
                    "meta": {
                        "service_name": "STANDARD SERVICE",
                        "rate_provider": "generic",
                    },
                    "service": "standard_service",
                    "selected_rate_id": "rat_ae51ec3f9ccd49a7b5385d7017ceaf99",
                    "test_mode": True,
                    "label_url": "/v1/shipments/shp_ff474b4a2ed34b7396c5c282b66c8593/label.pdf",
                    "invoice_url": None,
                },
                {
                    "id": "shp_f49473b250ae45bcb7e2a671f54f40ca",
                    "object_type": "shipment",
                    "tracking_url": "/v1/trackers/tst_overland/0000000135",
                    "shipper": {
                        "id": "adr_77cf815a63904280acb908b9357b727b",
                        "postal_code": "E1C4Z8",
                        "city": "Moncton",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "John Doe",
                        "company_name": "A corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "NB",
                        "suburb": None,
                        "residential": False,
                        "address_line1": "125 Church St",
                        "address_line2": None,
                        "validate_location": None,
                        "object_type": "address",
                        "validation": None,
                    },
                    "recipient": {
                        "id": "adr_470c247fbd6441aaaaf3c282d8e80637",
                        "postal_code": "V6M2V9",
                        "city": "Vancouver",
                        "federal_tax_id": None,
                        "state_tax_id": None,
                        "person_name": "Jane Doe",
                        "company_name": "B corp.",
                        "country_code": "CA",
                        "email": None,
                        "phone_number": "+1 514-000-0000",
                        "state_code": "BC",
                        "suburb": None,
                        "residential": True,
                        "address_line1": "5840 Oak St",
                        "address_line2": None,
                        "validate_location": False,
                        "object_type": "address",
                        "validation": None,
                    },
                    "parcels": [
                        {
                            "id": "pcl_00baac55ac8347718342fdc32f6104f5",
                            "weight": 1,
                            "width": 33.7,
                            "height": 18.2,
                            "length": 10,
                            "packaging_type": "medium_box",
                            "package_preset": None,
                            "description": None,
                            "content": None,
                            "is_document": False,
                            "weight_unit": "KG",
                            "dimension_unit": "CM",
                            "items": [
                                {
                                    "id": "cdt_2e947981ee1c4cec995573bc16386f96",
                                    "weight": 0.75,
                                    "weight_unit": "KG",
                                    "description": "Violet Suede Shoes",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 85.95,
                                    "value_currency": "USD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                }
                            ],
                            "freight_class": None,
                            "reference_number": "0000000135",
                            "object_type": "parcel",
                        },
                        {
                            "id": "pcl_1e82f5c3cd794daf88eabf206bb362ae",
                            "weight": 1,
                            "width": 46,
                            "height": 38,
                            "length": 32,
                            "packaging_type": None,
                            "package_preset": "canadapost_corrugated_medium_box",
                            "description": None,
                            "content": None,
                            "is_document": False,
                            "weight_unit": "KG",
                            "dimension_unit": "CM",
                            "items": [
                                {
                                    "id": "cdt_b262b1d38a4b4ab483422d58a2d9096e",
                                    "weight": 2,
                                    "weight_unit": "KG",
                                    "description": "Purple Leather Coat",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 349.99,
                                    "value_currency": "CAD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4ef9cc1b0c004f538ac0fb45ccc692c7",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                                {
                                    "id": "cdt_585a044ba05b4d849caf574eb0653f7e",
                                    "weight": 0.75,
                                    "weight_unit": "KG",
                                    "description": "Violet Suede Shoes",
                                    "quantity": 1,
                                    "sku": None,
                                    "value_amount": 85.95,
                                    "value_currency": "USD",
                                    "origin_country": None,
                                    "parent_id": "cdt_4b80710300ea4e22b67f6a488e588a34",
                                    "metadata": {
                                        "BGM": "040000000000016256",
                                        "CTL": "11253678",
                                        "DEPT": "DBR128",
                                        "XXNC": "138039C01",
                                        "NAD_UD": "570162",
                                        "RFF_CN": "037-2332855",
                                        "RFF_ON": "5424560",
                                        "RFF_AEM": "3901L",
                                        "RFF_AJY": "907",
                                    },
                                    "object_type": "commodity",
                                },
                            ],
                            "reference_number": "0000000134",
                            "object_type": "parcel",
                        },
                    ],
                    "services": [],
                    "options": {"shipment_date": "2022-03-25"},
                    "payment": {
                        "paid_by": "sender",
                        "currency": None,
                        "account_number": None,
                    },
                    "customs": None,
                    "rates": [
                        {
                            "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                            "object_type": "rate",
                            "carrier_name": "tst_overland",
                            "carrier_id": "tst-overland",
                            "currency": "CAD",
                            "service": "standard_service",
                            "discount": None,
                            "base_charge": 200,
                            "total_charge": 200,
                            "duties_and_taxes": None,
                            "transit_days": None,
                            "extra_charges": [],
                            "meta": {
                                "service_name": "STANDARD SERVICE",
                                "rate_provider": "tst_overland",
                                "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                            },
                            "test_mode": True,
                        }
                    ],
                    "reference": "Order #1073459962,394873849374",
                    "label_type": "PDF",
                    "carrier_ids": [],
                    "tracker_id": None,
                    "created_at": "2022-03-25 13:17:48.646853+00:00",
                    "metadata": {"order_ids": "1073459962,394873849374"},
                    "messages": [],
                    "status": "purchased",
                    "carrier_name": "generic",
                    "carrier_id": "tst-overland",
                    "tracking_number": "0000000135",
                    "shipment_identifier": "0000000135",
                    "selected_rate": {
                        "id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                        "object_type": "rate",
                        "carrier_name": "tst_overland",
                        "carrier_id": "tst-overland",
                        "currency": "CAD",
                        "service": "standard_service",
                        "discount": None,
                        "base_charge": 200,
                        "total_charge": 200,
                        "duties_and_taxes": None,
                        "transit_days": None,
                        "extra_charges": [],
                        "meta": {
                            "service_name": "STANDARD SERVICE",
                            "rate_provider": "tst_overland",
                            "carrier_connection_id": "car_9dac728533e841b09ec453178de5b3c3",
                        },
                        "test_mode": True,
                    },
                    "meta": {
                        "service_name": "STANDARD SERVICE",
                        "rate_provider": "generic",
                        "tracking_numbers": ["0000000135", "0000000134"],
                        "tracking_identifiers": ["0000000135", "0000000134"],
                    },
                    "service": "standard_service",
                    "selected_rate_id": "rat_1640580c8c5a454b865f68e8f236d6d9",
                    "test_mode": True,
                    "label_url": "/v1/shipments/shp_f49473b250ae45bcb7e2a671f54f40ca/label.pdf",
                    "invoice_url": None,
                },
            ],
            "test_mode": True,
            "created_at": "2022-03-21 14:21:55.986000+00:00",
        },
    ],
}


def create_barcode(value, options: dict = {}) -> str:
    barcode = Code128(value, writer=ImageWriter()).render(
        writer_options=dict(
            **{
                **dict(
                    quiet_zone=1.0,
                    module_width=0.5,
                    module_height=30.0,
                    font_size=1,
                    text_distance=0.0,
                    dpi=300,
                ),
                **options,
            }
        ),
        text="",
    )
    buffer = io.BytesIO()
    barcode.save(buffer, "PNG")

    return base64.b64encode(buffer.getvalue()).decode("utf-8")


def generate_code(data, code_type: str = "code128", options: dict = {}) -> str:
    barcode = treepoem.generate_barcode(
        barcode_type=code_type,
        data=data,
        options=options,
    )
    buffer = io.BytesIO()
    barcode.convert("1").save(buffer, "PNG")

    return base64.b64encode(buffer.getvalue()).decode("utf-8")


datetime = datetime
date_format = lib.fdatetime
